.. _api:

*************
API Reference
*************

.. module:: marshmallow

Schema
======


.. autoclass:: marshmallow.Schema
    :inherited-members:

.. autoclass:: marshmallow.SchemaOpts

.. autofunction:: marshmallow.pprint

.. _api_fields:

Fields
======

.. automodule:: marshmallow.fields
    :members:
    :private-members:

Decorators
==========

.. automodule:: marshmallow.decorators
    :members:

Validators
==========

.. automodule:: marshmallow.validate
    :members:

Utility Functions
=================

.. automodule:: marshmallow.utils
    :members:

Marshalling
===========

.. automodule:: marshmallow.marshalling
    :members:
    :private-members:

Class Registry
==============

.. automodule:: marshmallow.class_registry
    :members:

Exceptions
==========

.. automodule:: marshmallow.exceptions
    :members:
